==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_results/mp0024_001/EQUIPMENTINFO.java <==

package net.datastream.schemas.mp_results.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.RELIABILITYRANKINGID_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTWOCOMPLETION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0024_001}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISOBJID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISLAYER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGINDEXCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGSCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTINGAT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "classid",
    "categoryid",
    "preventwocompletion",
    "objtype",
    "statecode",
    "linearrefuom",
    "equipmentlength",
    "gisobjid",
    "gislayer",
    "sdmflag",
    "reliabilityrankingindexcode",
    "reliabilityrankingid",
    "reliabilityrankingscore",
    "startingat",
    "lineardirectionid"
})
@XmlRootElement(name = "EQUIPMENTINFO")
public class EQUIPMENTINFO {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "PREVENTWOCOMPLETION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String preventwocompletion;
    @XmlElement(name = "OBJTYPE")
    protected OBJTYPE objtype;
    @XmlElement(name = "STATECODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String statecode;
    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "EQUIPMENTLENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY equipmentlength;
    @XmlElement(name = "GISOBJID", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long gisobjid;
    @XmlElement(name = "GISLAYER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gislayer;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;
    @XmlElement(name = "RELIABILITYRANKINGINDEXCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reliabilityrankingindexcode;
    @XmlElement(name = "RELIABILITYRANKINGID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;
    @XmlElement(name = "RELIABILITYRANKINGSCORE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY reliabilityrankingscore;
    @XmlElement(name = "STARTINGAT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startingat;
    @XmlElement(name = "LINEARDIRECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type lineardirectionid;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the preventwocompletion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTWOCOMPLETION() {
        return preventwocompletion;
    }

    /**
     * Sets the value of the preventwocompletion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTWOCOMPLETION(String value) {
        this.preventwocompletion = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link OBJTYPE }
     *     
     */
    public OBJTYPE getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJTYPE }
     *     
     */
    public void setOBJTYPE(OBJTYPE value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the statecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATECODE() {
        return statecode;
    }

    /**
     * Sets the value of the statecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATECODE(String value) {
        this.statecode = value;
    }

    /**
     * Gets the value of the linearrefuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Sets the value of the linearrefuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Gets the value of the equipmentlength property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Sets the value of the equipmentlength property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

    /**
     * Gets the value of the gisobjid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGISOBJID() {
        return gisobjid;
    }

    /**
     * Sets the value of the gisobjid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGISOBJID(Long value) {
        this.gisobjid = value;
    }

    /**
     * Gets the value of the gislayer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGISLAYER() {
        return gislayer;
    }

    /**
     * Sets the value of the gislayer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGISLAYER(String value) {
        this.gislayer = value;
    }

    /**
     * Gets the value of the sdmflag property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Sets the value of the sdmflag property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

    /**
     * Gets the value of the reliabilityrankingindexcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGINDEXCODE() {
        return reliabilityrankingindexcode;
    }

    /**
     * Sets the value of the reliabilityrankingindexcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGINDEXCODE(String value) {
        this.reliabilityrankingindexcode = value;
    }

    /**
     * Gets the value of the reliabilityrankingid property.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Sets the value of the reliabilityrankingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

    /**
     * Gets the value of the reliabilityrankingscore property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRELIABILITYRANKINGSCORE() {
        return reliabilityrankingscore;
    }

    /**
     * Sets the value of the reliabilityrankingscore property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRELIABILITYRANKINGSCORE(QUANTITY value) {
        this.reliabilityrankingscore = value;
    }

    /**
     * Gets the value of the startingat property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTINGAT() {
        return startingat;
    }

    /**
     * Sets the value of the startingat property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTINGAT(QUANTITY value) {
        this.startingat = value;
    }

    /**
     * Gets the value of the lineardirectionid property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Sets the value of the lineardirectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_results/mp0024_001/EQUIPMENTINFO.java <==

package net.datastream.schemas.mp_results.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.RELIABILITYRANKINGID_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTWOCOMPLETION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0024_001}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATECODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISOBJID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISLAYER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGINDEXCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGSCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTINGAT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "classid",
    "categoryid",
    "preventwocompletion",
    "objtype",
    "statecode",
    "linearrefuom",
    "equipmentlength",
    "gisobjid",
    "gislayer",
    "sdmflag",
    "reliabilityrankingindexcode",
    "reliabilityrankingid",
    "reliabilityrankingscore",
    "startingat",
    "lineardirectionid"
})
@XmlRootElement(name = "EQUIPMENTINFO")
public class EQUIPMENTINFO {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "PREVENTWOCOMPLETION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String preventwocompletion;
    @XmlElement(name = "OBJTYPE")
    protected OBJTYPE objtype;
    @XmlElement(name = "STATECODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String statecode;
    @XmlElement(name = "LINEARREFUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linearrefuom;
    @XmlElement(name = "EQUIPMENTLENGTH", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY equipmentlength;
    @XmlElement(name = "GISOBJID", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long gisobjid;
    @XmlElement(name = "GISLAYER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gislayer;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;
    @XmlElement(name = "RELIABILITYRANKINGINDEXCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reliabilityrankingindexcode;
    @XmlElement(name = "RELIABILITYRANKINGID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;
    @XmlElement(name = "RELIABILITYRANKINGSCORE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY reliabilityrankingscore;
    @XmlElement(name = "STARTINGAT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startingat;
    @XmlElement(name = "LINEARDIRECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type lineardirectionid;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété preventwocompletion.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTWOCOMPLETION() {
        return preventwocompletion;
    }

    /**
     * Définit la valeur de la propriété preventwocompletion.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTWOCOMPLETION(String value) {
        this.preventwocompletion = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link OBJTYPE }
     *     
     */
    public OBJTYPE getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJTYPE }
     *     
     */
    public void setOBJTYPE(OBJTYPE value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété statecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATECODE() {
        return statecode;
    }

    /**
     * Définit la valeur de la propriété statecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATECODE(String value) {
        this.statecode = value;
    }

    /**
     * Obtient la valeur de la propriété linearrefuom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Définit la valeur de la propriété linearrefuom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentlength.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Définit la valeur de la propriété equipmentlength.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

    /**
     * Obtient la valeur de la propriété gisobjid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGISOBJID() {
        return gisobjid;
    }

    /**
     * Définit la valeur de la propriété gisobjid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGISOBJID(Long value) {
        this.gisobjid = value;
    }

    /**
     * Obtient la valeur de la propriété gislayer.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGISLAYER() {
        return gislayer;
    }

    /**
     * Définit la valeur de la propriété gislayer.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGISLAYER(String value) {
        this.gislayer = value;
    }

    /**
     * Obtient la valeur de la propriété sdmflag.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Définit la valeur de la propriété sdmflag.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingindexcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGINDEXCODE() {
        return reliabilityrankingindexcode;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingindexcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGINDEXCODE(String value) {
        this.reliabilityrankingindexcode = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingid.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingid.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingscore.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRELIABILITYRANKINGSCORE() {
        return reliabilityrankingscore;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingscore.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRELIABILITYRANKINGSCORE(QUANTITY value) {
        this.reliabilityrankingscore = value;
    }

    /**
     * Obtient la valeur de la propriété startingat.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTINGAT() {
        return startingat;
    }

    /**
     * Définit la valeur de la propriété startingat.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTINGAT(QUANTITY value) {
        this.startingat = value;
    }

    /**
     * Obtient la valeur de la propriété lineardirectionid.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Définit la valeur de la propriété lineardirectionid.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

}
